bayespy.inference.vmp.nodes.gaussian.GaussianGammaISOMoments.compute_dims_from_values
=====================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaISOMoments.compute_dims_from_values